Skip to contents

[Stable]

Faster than parsing JSON-LD when the combined graph has been exported via scripts/025-export-ntriples.R. Use this for iterative SPARQL work and as the data source when publishing to a Fuseki or Blazegraph endpoint.

Usage

load_combined_ntriples_graph(file_path = NULL)

Arguments

file_path

Character path to _combined.nt. Defaults to the standard location under data/processed/ntriples/.

Value

An rdf object.

Examples

if (FALSE) { # \dontrun{
rdf <- load_combined_ntriples_graph()
} # }