Load the pre-combined N-Triples file into an rdflib graph
Source:R/rdf-graph.R
load_combined_ntriples_graph.RdFaster than parsing JSON-LD when the combined graph has been exported via
scripts/025-export-ntriples.R. Use this for iterative SPARQL work and as
the data source when publishing to a Fuseki or Blazegraph endpoint.
See also
Other RDF graph loading:
load_combined_rdf_graph(),
load_single_framework_graph(),
load_unified_rdf_graph(),
make_demo_graph()